""" 物件新規作成の省力化ツール関数

各種関数

"""

# ライブラリのインポート --------------------------------------------
from typing import List
import ss7csv


def get_linename(
    name_line: List[str],
    name_line_x: List[str],
    name_line_y: List[str],
    count_span_x: int,
    count_span_y: int,
) -> None:
    """軸名の取得

    Args:
        name_line (List[str]): 軸名リスト
        name_line_x (List[str]): X軸名リスト
        name_line_y (List[str]): Y軸名リスト
        count_span_x (int): Xスパン数
        count_span_y (int): Yスパン数
    """
    # Y軸
    for i in range(count_span_y + 1):
        name_line.append("Y" + str(i + 1))
        name_line_y.append("Y" + str(i + 1))
    # X軸
    for i in range(count_span_x + 1):
        name_line.append("X" + str(i + 1))
        name_line_x.append("X" + str(i + 1))


def get_linezname(name_linez: List[str], count_linez: int) -> None:
    """層名の取得

    Args:
        name_linez (List[str]): 層名リスト
        count_linez (int): 層数
    """
    for i in reversed(range(count_linez)):
        if i == count_linez - 1:  # 最上層
            name_linez.append("RFL")
        else:  # 最上層以外
            name_linez.append(str(i + 1) + "FL")


def get_floorname(name_floor: List[str], count_floor: int) -> None:
    """階名

    Args:
        name_floor (List[str]): 階名リスト
        count_floor (int): 階数
    """
    for i in reversed(range(count_floor)):
        name_floor.append(str(i + 1) + "F")


def get_steelbox(size_type: List[str], data: List[List[str]], D: float) -> None:
    """指定したせいの角形鋼管を取得

    Args:
        size_type (List[str]): 鋼管サイズ, タイプ
        data (List[List[str]]): 入力CSVデータ
        D (float): せい
    """
    # name=角形鋼管
    tablename = "name=角形鋼管"
    data_box = ss7csv.GetTableData(data, tablename)

    # 指定したせいの角形鋼管を取得
    strBox = ""
    for i in range(len(data_box)):
        record = data_box[i]  # レコード
        H = record[3]  # H
        if H == "None":  # 空行など
            continue
        if float(H) >= float(D):
            strBox = record[2]
            strBox += "-"
            strBox += record[3] + "x"
            strBox += record[4] + "x"
            strBox += record[5] + "x"
            strBox += record[7]
            type = record[1]

            size_type[0] = strBox
            size_type[1] = type
            break


def get_steelh(size_type: List[str], data: List[List[str]], D: float) -> None:
    """指定したせいのＨ形鋼を取得

    Args:
        size_type (List[str]): H形鋼サイズ、タイプ
        data (List[List[str]]): 入力CSVデータ
        D (float): せい
    """
    # name=Ｈ形鋼
    tablename = "name=Ｈ形鋼"
    data_H = ss7csv.GetTableData(data, tablename)

    # 指定したせいのＨ形鋼を取得
    strH = ""
    for i in range(len(data_H)):
        record = data_H[i]  # レコード

        H = record[3]  # H
        if H == "None":  # 空行など
            continue
        if float(H) >= float(D):
            strH = record[2]
            strH += "-"
            strH += record[3] + "x"
            strH += record[4] + "x"
            strH += record[5] + "x"
            strH += record[6] + "x"
            strH += record[7]

            type = record[1]

            size_type[0] = strH
            size_type[1] = type
            break


def get_steelpipe(size_type: List[str], data: List[List[str]], D: float) -> None:
    """指定したせいの円形鋼管を取得

    Args:
        size_type (List[str]): 円形鋼管サイズ、タイプ
        data (List[List[str]]): 入力CSVデータ
        D (float): せい
    """
    # name=円形鋼管
    tablename = "name=円形鋼管"
    data_pipe = ss7csv.GetTableData(data, tablename)

    # 指定したせいの角形鋼管を取得
    strPipe = ""
    for i in range(len(data_pipe)):
        record = data_pipe[i]  # レコード
        H = record[3]  # H
        if H == "None":  # 空行など
            continue
        if float(H) >= float(D):
            strPipe = record[2]
            strPipe += "-"
            strPipe += record[3] + "x"
            strPipe += record[4]
            type = record[1]

            size_type[0] = strPipe
            size_type[1] = type
            break


def get_steel(
    size_type: List[str], data: List[List[str]], D: float, steelkind: str
) -> None:
    """指定したせいの角形鋼管を取得

    Args:
        size_type (List[str]): 角形鋼管のサイズ、タイプ
        data (List[List[str]]): 入力CSVデータ
        D (float): せい
        steelkind (str): 鋼材の種類
    """
    if "H形鋼１" in steelkind or "H形鋼２" in steelkind:
        get_steelh(size_type, data, D)
    elif "角形鋼管" in steelkind:
        get_steelbox(size_type, data, D)
    elif "円形鋼管" in steelkind:
        get_steelpipe(size_type, data, D)
