""" 物件新規作成の省力化ツール関数

入力データの読み込み

"""

# ライブラリのインポート --------------------------------------------
from openpyxl.worksheet.worksheet import Worksheet
from typing import List


def get_ss7ver(sheet: Worksheet) -> str:
    """対象のSS7のバージョン

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: 対象のSS7のバージョン
    """
    return sheet["B2"].value


def get_newdatadir(sheet: Worksheet) -> str:
    """新規作成データを保存するディレクトリ

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: 新規作成データを保存するディレクトリ
    """
    return sheet["B4"].value


def get_newdatapath(sheet: Worksheet) -> str:
    """新規作成データのパス

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: 新規作成データのパス
    """
    return sheet["B4"].value + "\\" + sheet["B3"].value + ".ikn"


def get_mainkozo(sheet: Worksheet) -> str:
    """主体構造

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: 主体構造
    """
    return sheet["B9"].value


def get_spancount(sheet: Worksheet, xy: int) -> int:
    """スパン数

    Args:
        sheet (Worksheet): 入力エクセルシート
        xy (int): 0:X軸、1:Y軸

    Returns:
        int: スパン数
    """
    if xy == 0:
        return sheet["B6"].value
    else:
        return sheet["B7"].value


def get_floorcount(sheet: Worksheet) -> int:
    """階数

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        int: 階数
    """
    return sheet["B8"].value


def get_span(sheet: Worksheet, xy: int) -> List[float]:
    """スパン

    Args:
        sheet (Worksheet): 入力エクセルシート
        xy (int): 0:X軸、1:Y軸

    Returns:
        List[float]: スパン
    """

    # スパン数
    count_span = get_spancount(sheet, xy)

    span: List[float] = []
    if xy == 0:
        # X軸
        for x in range(count_span):
            cellname: str = "E" + str(8 + x)
            if sheet[cellname].value is None:  # セルにデータがない
                break  # 読み込み終了
            span.append(sheet[cellname].value)
    else:
        # Y軸
        for y in range(count_span):
            cellname = "G" + str(8 + y)
            if sheet[cellname].value is None:  # セルにデータがない
                break  # 読み込み終了
            span.append(sheet[cellname].value)

    return span


def get_heightfloor(sheet: Worksheet) -> List[float]:
    """階高

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        List[float]: 階高
    """
    # 階数
    count_floor: int = get_floorcount(sheet)

    height_floor: List[float] = []
    for f in range(count_floor):
        cellname: str = "J" + str(8 + f)
        if sheet[cellname].value is None:  # セルにデータがない
            break  # 読み込み終了
        height_floor.append(sheet[cellname].value)

    return height_floor


def get_colfugolist(sheet: Worksheet) -> List[str]:
    """符号リスト（柱）

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        List[str]: 符号リスト（柱）
    """
    # 条件
    cond_fugo: str = sheet["B12"].value  # 全箇所同じ符号

    # スパン数
    count_span_x: int = get_spancount(sheet, 0)
    count_span_y: int = get_spancount(sheet, 1)

    colfugo: List[str] = []
    if cond_fugo == "全箇所同じ符号":
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y + 1):
                colfugo.append("C1")

    elif cond_fugo == "全個所異なる符号":
        col_fugo_no: int = 1
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y + 1):
                colfugo.append("C" + str(col_fugo_no))
                col_fugo_no += 1

    elif cond_fugo == "場所に応じた符号":
        # 隅柱C1、端柱C2、中柱C3
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y + 1):
                if (line_x == 0 or line_x == count_span_x) and (
                    line_y == 0 or line_y == count_span_y
                ):
                    colfugo.append("C1")
                elif line_x == 0 or line_x == count_span_x:
                    colfugo.append("C2")
                elif line_y == 0 or line_y == count_span_y:
                    colfugo.append("C2")
                else:
                    colfugo.append("C3")

    return colfugo


def get_girfugolist(sheet: Worksheet) -> List[str]:
    """符号リスト（梁）

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        List[str]: 符号リスト（梁）
    """
    # X方向外側梁GX1、X方向内側梁GX2
    # Y方向外側梁GY1、Y方向内側梁GY2

    # 条件
    cond_fugo: str = sheet["B12"].value  # 全箇所同じ符号

    # スパン数
    count_span_x: int = get_spancount(sheet, 0)
    count_span_y: int = get_spancount(sheet, 1)

    girfugo: List[str] = []
    if cond_fugo == "全箇所同じ符号":
        # X方向の梁
        for line_y in range(count_span_y + 1):
            for line_x in range(count_span_x):
                girfugo.append("G1")
        # Y方向の梁
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y):
                girfugo.append("G1")

    elif cond_fugo == "全個所異なる符号":
        # X方向の梁
        gir_fugo_no: int = 1
        for line_y in range(count_span_y + 1):
            for line_x in range(count_span_x):
                girfugo.append("GX" + str(gir_fugo_no))
                gir_fugo_no += 1
        # Y方向の梁
        gir_fugo_no = 1
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y):
                girfugo.append("GY" + str(gir_fugo_no))
                gir_fugo_no += 1

    elif cond_fugo == "場所に応じた符号":
        # X方向の梁
        for line_y in range(count_span_y + 1):
            for line_x in range(count_span_x):
                if line_y == 0 or line_y == count_span_y:
                    girfugo.append("GX1")
                else:
                    girfugo.append("GX2")
        # Y方向の梁
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y):
                if line_x == 0 or line_x == count_span_x:
                    girfugo.append("GY1")
                else:
                    girfugo.append("GY2")

    return girfugo


# 断面サイズ


def get_dcx_rc(sheet: Worksheet) -> float:
    """RC柱せい（X方向）

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: RC柱せい（X方向）
    """
    return sheet["B16"].value


def get_dcy_rc(sheet: Worksheet) -> float:
    """RC柱せい（Y方向）

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: RC柱せい（Y方向）
    """
    return sheet["B17"].value


def get_bb_rc(sheet: Worksheet) -> float:
    """RC梁幅

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: RC梁幅
    """
    return sheet["B18"].value


def get_db_rc(sheet: Worksheet) -> float:
    """RC梁せい

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: RC梁せい
    """
    return sheet["B19"].value


def get_fbb_rc(sheet: Worksheet) -> float:
    """基礎梁幅

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: 基礎梁幅
    """
    return sheet["B20"].value


def get_fdb_rc(sheet: Worksheet) -> float:
    """基礎梁せい

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: 基礎梁せい
    """
    return sheet["B21"].value


def get_concmate(sheet: Worksheet) -> str:
    """コンクリート材料

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: コンクリート材料
    """
    return sheet["B22"].value


def get_dc_s(sheet: Worksheet) -> float:
    """S柱せい

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: S柱せい
    """
    return sheet["B26"].value


def get_db_s(sheet: Worksheet) -> float:
    """S梁せい

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: S梁せい
    """
    return sheet["B30"].value


def get_load(sheet: Worksheet) -> float:
    """設計荷重

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        float: 設計荷重
    """
    return sheet["B13"].value


def get_scol_steel_kind(sheet: Worksheet) -> str:
    """S柱 鋼材の種類

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S柱 鋼材の種類
    """
    return sheet["B23"].value


def get_scol_steel_type(sheet: Worksheet) -> str:
    """S柱 鋼材の系列

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S柱 鋼材の系列
    """
    return sheet["B24"].value


def get_scol_steel_mate(sheet: Worksheet) -> str:
    """S柱 鋼材の材料

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S柱 鋼材の材料
    """
    return sheet["B25"].value


def get_sgir_steel_kind(sheet: Worksheet) -> str:
    """S梁 鋼材の種類

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S梁 鋼材の種類
    """
    return sheet["B27"].value


def get_sgir_steel_type(sheet: Worksheet) -> str:
    """S梁 鋼材の系列

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S梁 鋼材の系列
    """
    return sheet["B28"].value


def get_sgir_steel_mate(sheet: Worksheet) -> str:
    """S梁 鋼材の材料

    Args:
        sheet (Worksheet): 入力エクセルシート

    Returns:
        str: S梁 鋼材の材料
    """
    return sheet["B29"].value


def get_steel_list_pos_startcol(kind: str, type: str) -> str:
    """鋼材リストの読み込み位置（列）

    Args:
        kind (str): 鋼材の種類
        type (str): 鋼材の系列

    Returns:
        str: 鋼材リストの読み込み位置（列）
    """
    start_col: str = ""

    # 鋼材の系列の開始位置
    if kind == "H形鋼１":
        if type == "JIS_G3192-1977":
            start_col = "A"
        elif type == "JIS_G3192-2000":
            start_col = "I"
        elif type == "JIS_G3192-2008":
            start_col = "Q"
        elif type == "Tuned-H":
            start_col = "Y"

    elif kind == "H形鋼２":
        if type == "スーパーハイスレンドH":
            start_col = "A"
        elif type == "スーパーハイスレンドH(1996)":
            start_col = "I"
        elif type == "ハイパービーム(2022)":
            start_col = "Q"
        elif type == "ハイパービーム(2012)":
            start_col = "Y"
        elif type == "ハイパービーム(1996)":
            start_col = "AG"

    elif kind == "角形鋼管":
        if type == "BCP":
            start_col = "A"
        elif type == "BCR":
            start_col = "I"
        elif type == "BCR(旧規格)":
            start_col = "Q"
        elif type == "JBCR":
            start_col = "Y"
        elif type == "SHC":
            start_col = "AH"
        elif type == "SHC-EN":
            start_col = "AP"
        elif type == "SHCK":
            start_col = "AX"
        elif type == "STKR":
            start_col = "BF"
        elif type == "TSC":
            start_col = "BN"
    elif kind == "円形鋼管":
        if type == "JIS G3444-1994(STK)":
            start_col = "A"
        elif type == "JIS G3444-2010(STK)":
            start_col = "F"
        elif type == "JIS G3475-1996(STKN)":
            start_col = "K"
        elif type == "JIS G3475-2008(STKN)":
            start_col = "P"
        elif type == "標準":
            start_col = "U"
        elif type == "標準（旧規格）":
            start_col = "Z"

    return start_col


def get_steel_list_pos_endrow(kind: str, type: str) -> int:
    """鋼材リストの読み込み位置（行）

    Args:
        kind (str): 鋼材の種類
        type (str): 鋼材の系列

    Returns:
        int: 鋼材リストの読み込み位置（行）
    """
    end_row: int = 0

    # 鋼材の系列の開始位置
    if kind == "H形鋼１":
        if type == "JIS_G3192-1977":
            end_row = 91
        elif type == "JIS_G3192-2000":
            end_row = 68
        elif type == "JIS_G3192-2008":
            end_row = 58
        elif type == "Tuned-H":
            end_row = 14

    elif kind == "H形鋼２":
        if type == "スーパーハイスレンドH":
            end_row = 403
        elif type == "スーパーハイスレンドH(1996)":
            end_row = 260
        elif type == "ハイパービーム(2022)":
            end_row = 465
        elif type == "ハイパービーム(2012)":
            end_row = 330
        elif type == "ハイパービーム(1996)":
            end_row = 189

    elif kind == "角形鋼管":
        if type == "BCP":
            end_row = 130
        elif type == "BCR":
            end_row = 61
        elif type == "BCR(旧規格)":
            end_row = 59
        elif type == "JBCR":
            end_row = 47
        elif type == "SHC":
            end_row = 95
        elif type == "SHC-EN":
            end_row = 95
        elif type == "SHCK":
            end_row = 25
        elif type == "STKR":
            end_row = 43
        elif type == "TSC":
            end_row = 31
    elif kind == "円形鋼管":
        if type == "JIS G3444-1994(STK)":
            end_row = 132
        elif type == "JIS G3444-2010(STK)":
            end_row = 131
        elif type == "JIS G3475-1996(STKN)":
            end_row = 161
        elif type == "JIS G3475-2008(STKN)":
            end_row = 116
        elif type == "標準":
            end_row = 177
        elif type == "標準（旧規格）":
            end_row = 59

    return end_row
