""" 『SS7』物件新規作成の省力化ツールメイン処理

主体構造（純RC造、純S造）、スパン、階高、符号配置条件、
床荷重、柱断面、梁断面を入力するだけで、『SS7』の物件データを
新規作成し、断面算定まで行います。

SS7物件新規作成ツール.xlsxに主体構造等を入力し、
Python（Ver.3.9またはVer.3.10）でこのファイルを指定して実行してください。

"""

# ライブラリのインポート --------------------------------------------
import os
import sys
import subprocess
import openpyxl
from typing import List

import ss7csv
import ss7
import inputreader
import inputwriter
import function

# 入力データの読み込み --------------------------------------------

# スクリプトのディレクトリを取得
script_dir: str = os.path.dirname(__file__)
script_dir += "\\"

# 新規作成用CSVひな型
path_input_0: str = script_dir + "input0.csv"

# 新規作成用CSV
path_input: str = script_dir + "input.csv"

# 新規作成用入力データファイル
path_xls: str = script_dir + "SS7物件新規作成ツール.xlsx"

# 必要なファイルのチェック
if not os.path.exists(path_input_0):
    print("新規作成用CSVのひな型（input0.csv）が存在しません。")
    sys.exit()
if not os.path.exists(path_xls):
    print("新規作成用入力データファイル（SS7物件新規作成ツール.xlsx）が存在しません。")
    sys.exit()


# 新規作成用入力データファイルを開く
wb: openpyxl.Workbook = openpyxl.load_workbook(path_xls)
sheet = wb["入力"]

# 新規作成データパス
path_data: str = inputreader.get_newdatapath(sheet)

# 必要なディレクトリのチェック
dir_data: str = inputreader.get_newdatadir(sheet)
if not os.path.exists(dir_data):
    print(
        "物件フォルダパス："
        + dir_data
        + " が存在しません。あらかじめ作成して実行してください。"
    )
    sys.exit()

# 対象のSS7バージョン
ss7_ver: str = inputreader.get_ss7ver(sheet)

# 主体構造  ※ RCまたはSのみ
main_kozo: str = inputreader.get_mainkozo(sheet)
if main_kozo != "RC" and main_kozo != "S":
    print(
        "主体構造にRCまたはS以外の構造が指定されています。SS7物件新規作成ツール.xlsxを確認してください。"
    )
    sys.exit()

# 計算ルート 構造種別（主体構造に同じ）
route_kozo: int = 0
if main_kozo == "RC":
    route_kozo = 2
elif main_kozo == "S":
    route_kozo = 1

# スパン数
count_span_x: int = inputreader.get_spancount(sheet, 0)
count_span_y: int = inputreader.get_spancount(sheet, 1)

# 階数
count_floor: int = inputreader.get_floorcount(sheet)

# 層数
count_linez: int = int(count_floor) + 1

# スパン
span_x: List[float] = inputreader.get_span(sheet, 0)
span_y: List[float] = inputreader.get_span(sheet, 1)
# スパンチェック
if len(span_x) + len(span_y) != count_span_x + count_span_y:
    print(
        "スパンのデータ数がスパン数と異なります。SS7物件新規作成ツール.xlsxを確認してください。"
    )
    sys.exit()

# 階高
height_floor: List[float] = inputreader.get_heightfloor(sheet)
# 階高チェック
if len(height_floor) != count_floor:
    print(
        "階高のデータ数が階数と異なります。SS7物件新規作成ツール.xlsxを確認してください。"
    )
    sys.exit()

# 符号リスト
list_colfugo: List[str] = inputreader.get_colfugolist(sheet)  # 柱
list_girfugo: List[str] = inputreader.get_girfugolist(sheet)  # 梁

# 断面サイズ
if main_kozo == "RC":
    Dcx: float = inputreader.get_dcx_rc(sheet)  # 柱せい X方向
    Dcy: float = inputreader.get_dcy_rc(sheet)  # 柱せい Y方向
    Bb: float = inputreader.get_bb_rc(sheet)  # 梁幅
    Db: float = inputreader.get_db_rc(sheet)  # 梁せい

elif main_kozo == "S":
    # S柱 鋼材の種類、系列
    steelkind_col: str = inputreader.get_scol_steel_kind(sheet)
    steeltype_col: str = inputreader.get_scol_steel_type(sheet)
    steelmate_col: str = inputreader.get_scol_steel_mate(sheet)
    # S柱せい
    Dcs: float = inputreader.get_dc_s(sheet)
    # S梁 鋼材の種類、系列、材料
    steelkind_gir: str = inputreader.get_sgir_steel_kind(sheet)
    steeltype_gir: str = inputreader.get_sgir_steel_type(sheet)
    steelmate_gir: str = inputreader.get_sgir_steel_mate(sheet)
    # S梁せい
    Dbs: float = inputreader.get_db_s(sheet)

# コンクリート材料
concmate: str = inputreader.get_concmate(sheet)

# 基礎梁 梁、せい
FBb: float = inputreader.get_fbb_rc(sheet)
FDb: float = inputreader.get_fdb_rc(sheet)

# 設計荷重
Load: float = inputreader.get_load(sheet)


# 入力CSVファイルの作成 --------------------------------------------

# ひな型の読み込み
data: List[List[str]] = ss7csv.GetCsvData(path_input_0)

# name=基本事項 主体構造 S
inputwriter.write_mainkozo_s(data, main_kozo)

# name=基本事項 主体構造 RC
inputwriter.write_mainkozo_rc(data, main_kozo)

# name=基本事項 計算ルート 構造種別
inputwriter.write_routekozo(data, route_kozo)

# name=基本事項 X方向スパン数
inputwriter.write_span_x(data, count_span_x)

# name=基本事項 Y方向スパン数
inputwriter.write_span_y(data, count_span_y)

# name=基本事項 全階数
inputwriter.write_floorcount(data, count_floor)

# 軸名の生成
name_line: List[str] = []
name_line_x: List[str] = []  # 基準スパン用
name_line_y: List[str] = []  # 基準スパン用
function.get_linename(name_line, name_line_x, name_line_y, count_span_x, count_span_y)

# 層名の生成
name_linez: List[str] = []
function.get_linezname(name_linez, count_linez)

# 階名の生成
name_floor: List[str] = []
function.get_floorname(name_floor, count_floor)

# name=軸名
inputwriter.write_linename(data, name_line, count_span_x, count_span_y)

# name=層名
inputwriter.write_linezname(data, name_linez, count_linez)

# name=階名
inputwriter.write_floorname(data, name_floor, count_floor)

# name=各層主体構造
inputwriter.write_linezkozo(data, main_kozo, name_linez, count_linez)

# name=基準スパン長
inputwriter.write_span_length(
    data, span_x, span_y, name_line_x, name_line_y, count_span_x, count_span_y
)

# name=標準階高
inputwriter.write_floor_height(data, height_floor, name_floor, count_floor)

# name=標準階高と梁心の差　の初期化
inputwriter.write_gircenter(data, name_linez)

# name=構造心とのズレ　の初期化
inputwriter.write_kozocenter(data, name_line)

# name=部材の寄り　の初期化
inputwriter.write_offset_xy(data, name_line)

# name=梁のレベル調整　の初期化
inputwriter.write_offset_ud(data, name_linez)

# name=二重スラブの有無　の初期化
inputwriter.write_doubleslab(data, name_linez)

# name=各層床面積　の初期化
inputwriter.write_slab_area(data, name_linez)

# name=ダミー層　の初期化
inputwriter.write_linez_dummy(data, name_linez)

# name=柱配置
inputwriter.write_colpos(
    data,
    list_colfugo,
    name_floor,
    name_line_x,
    name_line_y,
    count_floor,
    count_span_x,
    count_span_y,
)

# name=大梁配置
inputwriter.write_girpos(
    data,
    list_girfugo,
    name_linez,
    name_line_x,
    name_line_y,
    count_linez,
    count_span_x,
    count_span_y,
)

# name=床総荷重
inputwriter.write_slab_load(data, Load)

# name=床配置
inputwriter.write_slab_pos(
    data, name_linez, name_line_x, name_line_y, count_linez, count_span_x, count_span_y
)

# name=標準使用材料,tab=コンクリート・鉄筋
inputwriter.write_concmate(data, concmate)

if main_kozo == "RC":

    # name=RC柱断面
    inputwriter.write_rc_col_sect(data, list_colfugo, Dcx, Dcy, name_floor, count_floor)

    # name=RC梁断面
    inputwriter.write_rc_gir_sect(
        data, list_girfugo, Bb, Db, FBb, FDb, name_linez, 0, count_linez
    )

if main_kozo == "S":

    # S柱の鋼材リスト
    inputwriter.write_steel_list(data, wb, steelkind_col, steeltype_col)

    # S柱の材料
    inputwriter.write_steelmate_col(data, steelkind_col, steelmate_col)

    # S梁の鋼材リスト
    inputwriter.write_steel_list(data, wb, steelkind_gir, steeltype_gir)

    # S梁の材料
    inputwriter.write_steelmate_gir(data, steelmate_gir)

    # S柱 指定したせいの鋼材を取得
    size_type_col: List[str] = ["", ""]
    function.get_steel(size_type_col, data, Dcs, steelkind_col)
    if size_type_col[0] == "":
        print(
            "S柱について、指定したせいの鋼材が見つかりませんでした。SS7物件新規作成ツール.xlsxを確認してください。"
        )
        sys.exit()

    # S梁 指定したせいの鋼材を取得
    size_type_gir: List[str] = ["", ""]
    function.get_steel(size_type_gir, data, Dbs, steelkind_gir)
    if size_type_gir[0] == "":
        print(
            "S梁について、指定したせいの鋼材が見つかりませんでした。SS7物件新規作成ツール.xlsxを確認してください。"
        )
        sys.exit()

    # name=S柱断面
    inputwriter.write_s_col_sect(
        data,
        list_colfugo,
        steelkind_col,
        size_type_col[0],
        size_type_col[1],
        name_floor,
        count_floor,
    )

    # name=S梁断面
    inputwriter.write_s_gir_sect(
        data,
        list_girfugo,
        steelkind_gir,
        size_type_gir[0],
        size_type_gir[1],
        name_linez,
        0,
        count_linez - 1,
    )

    # name=RC梁断面（基礎梁）
    inputwriter.write_rc_gir_sect(
        data, list_girfugo, 0, 0, FBb, FDb, name_linez, count_linez - 1, count_linez
    )


# 新規作成用CSVに書き込み
ss7csv.WriteCsv(path_input, data)


# SS7新規作成、計算 --------------------------------------------
print("SS7新規作成、計算中・・・")
bSS7Start: bool = ss7.SS7Start(ss7_ver, path_input, path_data)
if bSS7Start:
    print("SS7新規作成、計算が終了しました。")

    # 物件フォルダを開く --------------------------------------------
    subprocess.Popen(["explorer", path_data])
    print("エクスプローラで物件フォルダを表示しました。")

# 中間ファイルの削除 --------------------------------------------
#   ・SS7入力CSVファイル（input.csv）を削除します。
if os.path.exists(path_input):
    os.remove(path_input)
