""" 物件新規作成の省力化ツール関数

SS7のCSVを扱うための関数

"""

# ライブラリのインポート --------------------------------------------
import csv
from typing import List


def GetCsvData(path_input: str) -> List[List[str]]:
    """入力CSVを配列に格納

    Args:
        path_input (str): 入力CSVのパス

    Returns:
        List[List[str]]: 入力CSVデータ
    """
    # 入力CSV
    input_csv_file = open(path_input, "r", encoding="cp932")

    # 入力CSVファイルの読み込み
    reader = csv.reader(input_csv_file)

    # 入力CSVファイルを配列に格納
    data = list(reader)

    # 入力CSVファイルを閉じる
    input_csv_file.close()

    return data


def GetRowIndex_name(
    data: List[List[str]],
    tablename: str,
    tabname: str,
    name1: str,
    name2: str = "",
    name3: str = "",
) -> int:
    """対象の文字列の行インデックスを取得

    Args:
        data (List[List[str]]): 入力CSVデータ
        tablename (str): テーブル名
        tabname (str): タブ名
        name1 (str): キーワード１
        name2 (str, optional): キーワード２. Defaults to "".
        name3 (str, optional): キーワード３. Defaults to "".

    Returns:
        int: 対象の文字列の行インデックス
    """
    table_find: bool = False  # テーブルが見つかったかどうかのフラグ
    tab_find: bool = False  # タブが見つかったかどうかのフラグ

    # タブの指定なし
    if len(tabname) == 0:
        tab_find = True

    # 対象のレコードIndexを取得
    for rowindex, line in enumerate(data):

        count: int = len(line)

        if 0 < count:

            # テーブルの検索

            # 1列目のデータ
            column1: str = line[0]

            # テーブルの検索
            if not table_find or not tab_find:

                # テーブルの検索
                if column1 == tablename:  # テーブルが見つかった
                    table_find = True

                    # タブの検索
                    if count > 1:
                        column2: str = line[1]  # 2列目のデータ
                        if column2 == tabname:  # タブが見つかった
                            tab_find = True

                continue

        # フィールドの検索
        if name1 in line:  # 対象のフィールド名（キーワード１）あり

            if len(name2) > 0:  # フィールド名（キーワード２）の指定あり
                if name2 in line:  # 対象の文字列あり

                    if len(name3) > 0:  # フィールド名（キーワード３）の指定あり
                        if name3 in line:  # 対象の文字列あり
                            return rowindex
                    else:  # フィールド名（キーワード３）の指定なし
                        return rowindex

            else:  # フィールド名（キーワード２）の指定なし
                return rowindex

    return -1


def GetDataRowIndex(data: List[List[str]], tablename: str, tabname: str = "") -> int:
    """対象のテーブルのレコード開始位置を取得

    Args:
        data (List[List[str]]): 入力CSVデータ
        tablename (str): テーブル名
        tabname (str, optional): タブ名. Defaults to "".

    Returns:
        int: 対象のテーブルのレコード開始位置
    """
    table_find: bool = False  # テーブルが見つかったかどうかのフラグ
    tab_find: bool = False  # タブが見つかったかどうかのフラグ

    data_find: bool = False  # データ行が見つかったかどうかのフラグ

    # タブの指定なし
    if len(tabname) == 0:
        tab_find = True

    # 対象のレコードIndexを取得
    for rowindex, line in enumerate(data):

        count: int = len(line)

        if 0 < count:

            # テーブルの検索

            # 1列目のデータ
            column1: str = line[0]

            # テーブルの検索
            if not table_find or not tab_find:

                # テーブルの検索
                if column1 == tablename:  # テーブルが見つかった
                    table_find = True

                    # タブの検索
                    if count > 1:
                        column2: str = line[1]  # 2列目のデータ
                        if column2 == tabname:  # タブが見つかった
                            tab_find = True

                continue

            # データ開始位置の検索
            elif not data_find:

                if column1 == "<data>":  # 1列目のデータが“<data>”の場合

                    # 以降をデータ行と認識する
                    data_find = True

                    # 次の行から開始
                    return rowindex + 1

    return -1


def GetRecordCnt(data: List[List[str]], tablename: str, casename: str = "") -> int:
    """対象のテーブルのレコード数

    Args:
        data (List[List[str]]): 入力CSVデータ
        tablename (str): テーブル名
        casename (str, optional): ケース名. Defaults to "".

    Returns:
        List[List[str]]: 対象のテーブルのレコード数
    """
    # レコード数
    count_record: int = 0

    # 対象のテーブルのレコード開始位置を取得
    datarowindex: int = GetDataRowIndex(data, tablename, casename)

    # レコードが見つかった
    if datarowindex >= 0:

        # 対象のキーのレコードIndexを取得
        count_data: int = len(data)  # データの全行数

        # 対象のテーブルのレコード開始位置から検索
        for rowindex in range(datarowindex, count_data - 1):

            # レコード
            line: List[str] = data[rowindex]

            count: int = len(line)
            if 0 < count:

                count_record += 1

            else:
                return count_record

    return count_record


def GetTableData(
    data: List[List[str]], tablename: str, casename: str = ""
) -> List[List[str]]:
    """対象のテーブルの全レコードの取得

    Args:
        data (List[List[str]]): 入力CSVデータ
        tablename (str): テーブル名
        casename (str, optional): ケース名. Defaults to "".

    Returns:
        List[List[str]]: 対象のテーブルの全レコード
    """
    # 全レコード
    line_all: List[List[str]] = []

    # 対象のテーブルのレコード開始位置を取得
    datarowindex: int = GetDataRowIndex(data, tablename, casename)

    # レコードが見つかった
    if datarowindex >= 0:

        # 対象のキーのレコードIndexを取得
        count_data: int = len(data)  # データの全行数

        # 対象のテーブルのレコード開始位置から検索
        for rowindex in range(datarowindex, count_data - 1):

            # レコード
            line: List[str] = data[rowindex]

            count: int = len(line)
            if 0 < count:

                line_all.append(line)

            else:
                return line_all

    return line_all


# CSVへの書き込み
def WriteCsv(path: str, data: List[List[str]]) -> None:
    """_summary_

    Args:
        path (str): CSVファイルのパス
        data (List[List[str]]): CSVデータ
    """
    csv_file = open(path, "w", newline="", encoding="cp932")
    writer = csv.writer(csv_file)
    writer.writerows(data)
    csv_file.close()


def Delete_Record(data: List[List[str]], tablename: str) -> None:
    """レコードの削除

    Args:
        data (List[List[str]]): CSVデータ
        tablename (str): テーブル名
    """
    # レコード開始位置
    rowindex: int = GetDataRowIndex(data, tablename)

    # レコードを削除
    count_record: int = GetRecordCnt(data, tablename)
    for i in range(count_record):
        del data[rowindex]  # 削除していくので同じインデックスを削除


def Init_Record(
    data: List[List[str]], tablename: str, list_key: List[str], init_value: int
) -> None:
    """レコードの初期化

    Args:
        data (List[List[str]]): CSVデータ
        tablename (str): テーブル名
        list_key (List[str]): キー
        init_value (int): 初期値
    """
    # レコードを削除
    Delete_Record(data, tablename)

    # レコード開始位置
    rowindex: int = GetDataRowIndex(data, tablename)

    # 初期値を追加
    for i in range(len(list_key)):
        data.insert(rowindex + i, [list_key[i], init_value, "<RE>"])


def Init_Record_str(
    data: List[List[str]], tablename: str, list_key: List[str], init_value: str
) -> None:
    """レコードの初期化

    Args:
        data (List[List[str]]): CSVデータ
        tablename (str): テーブル名
        list_key (List[str]): キー
        init_value (str): 初期値
    """
    # レコードを削除
    Delete_Record(data, tablename)

    # レコード開始位置
    rowindex: int = GetDataRowIndex(data, tablename)

    # 初期値を追加
    for i in range(len(list_key)):
        data.insert(rowindex + i, [list_key[i], init_value, "<RE>"])
